
# coding: utf-8

# ## Marginalize a combined result, instead of profiling it

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append( "." ); import smodels_paths


# In[2]:


from smodels.theory import slhaDecomposer
from smodels.installation import installDirectory
from smodels.theory.theoryPrediction import theoryPredictionsFor
from smodels.tools.physicsUnits import fb, GeV
from smodels.experiment.databaseObj import Database


# In[3]:


# load the official database
database = Database("official")


# In[4]:


# however filter out the aggregated CMS-SUS-16-050 result
expResult = database.getExpResults( analysisIDs=["CMS-PAS-SUS-16-052-agg"] )[0]


# In[5]:


# Check: print out the experimental result
print ( expResult )


# In[6]:


# We look at a model that has gluinos -> t t LSP
filename="%s/inputFiles/slha/gluinoToTops.slha" % installDirectory()


# In[7]:


# perform the decompoistion
topList = slhaDecomposer.decompose(filename)
print ( topList )


# In[8]:


# obtain the theory predictions with marginalize=False
predProf = theoryPredictionsFor(expResult, topList, combinedResults=True, marginalize=False ) 


# In[9]:


# print the combined upper limit
print ( predProf[1].getUpperLimit().asNumber(fb) )


# In[ ]:


# obtain the theory predictions with marginalize=True
predMarg = theoryPredictionsFor(expResult, topList, combinedResults=True, marginalize=True )


# In[ ]:


# print the combined upper limit
print ( predMarg[1].getUpperLimit().asNumber(fb) )

